@@ -76,6 +76,7 @@ MainWindow::MainWindow(QWidget *parent) :
   m_refreshPackageLists = false;
   m_refreshForeignPackageList = false;
   m_cic = nullptr;
+  m_ignoredStringList = Package::extractIgnorePkgList();
   m_outdatedStringList = new QStringList();
   m_checkupdatesStringList = new QStringList();
   m_checkUpdatesNameNewVersion = new QHash<QString, QString>();
@@ -112,11 +113,6 @@ MainWindow::MainWindow(QWidget *parent) :
 
   //Here we try to speed up first pkg list build!
   m_time->start();
-
-  /*retrieveOutdatedPackageList();
-  retrieveUnrequiredPackageList();
-  retrieveForeignPackageList();*/
-
   ui->setupUi(this);
   switchToViewAllPackages();  
 
@@ -135,6 +131,21 @@ MainWindow::MainWindow(QWidget *parent) :
  */
 MainWindow::~MainWindow()
 {
+  if (isAURGroupSelected())
+  {
+    if (m_savedSearchMethod->objectName() == QStringLiteral("actionSearchByName"))
+      SettingsManager::setSearchMethod(SearchMethod::ectn_SEARCH_BY_NAME);
+    else if (m_savedSearchMethod->objectName() == QStringLiteral("actionSearchByDescription"))
+      SettingsManager::setSearchMethod(SearchMethod::ectn_SEARCH_BY_DESCRIPTION);
+  }
+  else
+  {
+    if (ui->actionSearchByName->isChecked())
+      SettingsManager::setSearchMethod(SearchMethod::ectn_SEARCH_BY_NAME);
+    else if (ui->actionSearchByDescription->isChecked())
+      SettingsManager::setSearchMethod(SearchMethod::ectn_SEARCH_BY_DESCRIPTION);
+  }
+
   savePackageColumnWidths();
   UnixCommand::removeTemporaryFiles();
 
@@ -392,7 +403,11 @@ void MainWindow::onPackageGroupChanged()
   {
     if (m_commandExecuting == ectn_NONE && m_initializationCompleted) m_actionSwitchToForeignTool->setEnabled(true);
     m_actionLastSearchMethod->setChecked(true);
-    tvPackagesSearchColumnChanged(ui->actionSearchByName);
+
+    if (m_savedSearchMethod != nullptr)
+      tvPackagesSearchColumnChanged(m_savedSearchMethod);
+    else
+      tvPackagesSearchColumnChanged(ui->actionSearchByName);
   }
   else m_actionSwitchToForeignTool->setEnabled(false);
 }
@@ -492,9 +507,12 @@ void MainWindow::showAnchorDescription(const QUrl &link)
     pkgDesc.description = package->description;
     pkgDesc.isForeign = (package->status == ectn_FOREIGN || package->status == ectn_FOREIGN_OUTDATED);
 
-    f = QtConcurrent::run(showPackageDescriptionExt, pkgDesc);
-    g_fwToolTipInfo.setFuture(f);
-    connect(&g_fwToolTipInfo, SIGNAL(finished()), this, SLOT(execToolTip()));
+    if (SettingsManager::getEnablePackageTooltips())
+    {
+      f = QtConcurrent::run(showPackageDescriptionExt, pkgDesc);
+      g_fwToolTipInfo.setFuture(f);
+      connect(&g_fwToolTipInfo, SIGNAL(finished()), this, SLOT(execToolTip()));
+    }
   }
 }
 
@@ -964,7 +982,10 @@ bool MainWindow::isPackageInstalled(const QString &pkgName)
 void MainWindow::tvPackagesSearchColumnChanged(QAction *actionSelected)
 {
   if (!isAURGroupSelected())
+  {
     m_actionLastSearchMethod = actionSelected;
+    m_savedSearchMethod = m_actionLastSearchMethod;
+  }
 
   //We are in the realm of tradictional NAME search
   if (actionSelected->objectName() == ui->actionSearchByName->objectName())
@@ -1167,13 +1188,22 @@ void MainWindow::execContextMenuPackages(QPoint point)
         menu->addAction(ui->actionFindFileInPackage);
       }
       if (!menu->actions().isEmpty()) menu->addSeparator();
+
+      if (package->status == ectn_IGNORED)
+      {
+        menu->addSeparator();
+        menu->addAction(ui->actionRemoveFromIgnored);
+        menu->addAction(m_actionChangeInstallReason);
+      }
     }
 
     bool allInstallable = true;
     bool allRemovable = true;
     int numberOfSelPkgs = selectedRows.count();
     int numberOfAUR = 0;
+    int numberOfIgnored = 0;
     int numberOfOutdated = 0;
+    int numberOfIntalled = 0;
 
     for(QModelIndex item: selectedRows)
     {
@@ -1185,10 +1215,18 @@ void MainWindow::execContextMenuPackages(QPoint point)
         numberOfAUR++;
       }
       if (package->outdated()) numberOfOutdated ++;
+
       if (!package->installed())
       {
         allRemovable = false;
       }
+
+      if (package->status == ectn_IGNORED)
+      {
+        numberOfIgnored++;
+        allInstallable = false;
+        allRemovable = false;
+      }
     }
 
     if (allInstallable) // implicitly foreign packages == 0
@@ -1200,10 +1238,14 @@ void MainWindow::execContextMenuPackages(QPoint point)
       }
       else if (allRemovable && numberOfOutdated == numberOfSelPkgs)
       {
+        menu->addAction(ui->actionAddToIgnored);
         ui->actionInstall->setText(StrConstants::getUpdate());
       }
       else if (allRemovable)
+      {
+        menu->addAction(ui->actionAddToIgnored);
         ui->actionInstall->setText(StrConstants::getReinstall());
+      }
 
       menu->addAction(ui->actionInstall);
 
@@ -1218,6 +1260,12 @@ void MainWindow::execContextMenuPackages(QPoint point)
         }
       }
     }
+    else if (!allInstallable && numberOfIgnored == numberOfSelPkgs)
+    {
+      //There are only ignored packages here
+      menu->addAction(ui->actionRemoveFromIgnored);
+      menu->addAction(m_actionChangeInstallReason);
+    }
     else if (!allInstallable && numberOfAUR == numberOfSelPkgs)
     {
       QString aurPkg;
@@ -1230,6 +1278,7 @@ void MainWindow::execContextMenuPackages(QPoint point)
 
         if (package->installed() || package->outdated())
         {
+          numberOfIntalled++;
           if (package->outdated()) ++numOutdated;
           allInstalled = true;
         }
@@ -1241,10 +1290,12 @@ void MainWindow::execContextMenuPackages(QPoint point)
 
       if (allInstalled && (numOutdated==numberOfSelPkgs))
       {
+        menu->addAction(ui->actionAddToIgnored);
         ui->actionInstall->setText(StrConstants::getUpdate());
       }
-      else if (allInstalled)
+      else if (numberOfIntalled==numberOfSelPkgs)
       {
+        menu->addAction(ui->actionAddToIgnored);
         ui->actionInstall->setText(StrConstants::getReinstall());
       }
       else
