@@ -39,6 +39,7 @@ PacmanExec::PacmanExec(QObject *parent) : QObject(parent)
   m_iLoveCandy = UnixCommand::isILoveCandyEnabled();
   m_debugMode = false;
   m_processWasCanceled = false;
+  m_retrievingPackages = false;
   m_parsingAPackageChange = false;
   m_numberOfPackages = 0;
   m_packageCounter = 0;
@@ -252,6 +253,11 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
     msg = QLatin1String("<br>") + msg;
   }
 
+  if (msg.indexOf(QLatin1String(":: Retrieving packages...")) != -1)
+  {
+    m_retrievingPackages = true;
+  }
+
   if (SettingsManager::getShowPackageNumbersOutput())
   {
     QRegularExpression re(QStringLiteral("Packages? \\(\\d+\\)"));
@@ -362,12 +368,12 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
 
             if(!target.isEmpty())
             {
-              prepareTextToPrint(QLatin1String("<b><font color=\"#b4ab58\">") + target + QLatin1String("</font></b>")); //#C9BE62
+              prepareTextToPrint(QLatin1String("<b><font color=\"#b4ab58\">") + target + QLatin1String("</font></b>"));
             }
           }
           else
           {
-            prepareTextToPrint(QLatin1String("<b><font color=\"#b4ab58\">") + msg + QLatin1String("</font></b>")); //#C9BE62
+            prepareTextToPrint(QLatin1String("<b><font color=\"#b4ab58\">") + msg + QLatin1String("</font></b>"));
           }
         }
       }
@@ -403,11 +409,6 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
                   prepareTextToPrint(QLatin1String("<b><font color=\"#FF8040\">") +
                                       StrConstants::getSyncing() + QLatin1Char(' ') + target + QLatin1String("</font></b>"));
                 }
-                /*else if (m_commandExecuting != ectn_SYNC_DATABASE)
-                {
-                  prepareTextToPrint(QLatin1String("<b><font color=\"#b4ab58\">") +
-                                      target + QLatin1String("</font></b>")); //#C9BE62
-                }*/
               }
             }
           }
@@ -456,6 +457,7 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
     msg.remove(QRegularExpression(QStringLiteral("qt.qpa.plugin:.+")));
     msg.remove(QRegularExpression(QStringLiteral("qt.qpa.xcb:.+")));
     msg.remove(QRegularExpression(QStringLiteral("qt.qpa.wayland.+")));
+    msg.remove(QRegularExpression(QStringLiteral("qt.xkb.compose:.+")));
     msg.remove(QRegularExpression(QStringLiteral("\\[sudo\\] password for.+")));
     msg.remove(QRegularExpression(QStringLiteral("Icon theme \".+")));
     msg.remove(QRegularExpression(QStringLiteral("Gtk-Message:.+")));
@@ -535,10 +537,11 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
           }
           else if (m_commandExecuting == ectn_INSTALL || m_commandExecuting == ectn_REMOVE || m_commandExecuting == ectn_SYSTEM_UPGRADE)
           {
-            if (!altMsg.contains(QRegularExpression(QStringLiteral("\\s"))) && !altMsg.contains(QStringLiteral("--")) && altMsg.contains(QStringLiteral("-")))
+            if (!altMsg.contains(QRegularExpression(QStringLiteral("\\s"))) && !altMsg.contains(QStringLiteral("--"))
+                && altMsg.contains(QStringLiteral("-")) && m_retrievingPackages)
             {
               prepareTextToPrint(QLatin1String("<b><font color=\"#b4ab58\">") +
-                                altMsg + QLatin1String("</font></b>")); //#C9BE62
+                                altMsg + QLatin1String("</font></b>"));
             }
             else if (altMsg != QStringLiteral("E"))
             {
@@ -581,6 +584,7 @@ void PacmanExec::prepareTextToPrint(QString str, TreatString ts, TreatURLLinks t
 
   //If the string waiting to be printed is from curl status OR any other unwanted string...
   if (!str.contains(QRegularExpression(QStringLiteral("<font color"))))
+  {
     if ((str.contains(QRegularExpression(QStringLiteral("\\(\\d"))) &&
          (!str.contains(QLatin1String("target"), Qt::CaseInsensitive)) &&
          (!str.contains(QLatin1String("package"), Qt::CaseInsensitive))) ||
@@ -595,8 +599,12 @@ void PacmanExec::prepareTextToPrint(QString str, TreatString ts, TreatURLLinks t
     {
       return;
     }
-
-  if (str.indexOf(QLatin1String("o o")) != -1) return;
+  }
+  else if (str.indexOf(QLatin1String("o o")) != -1) return;
+  else if ((str.indexOf(QLatin1String("upgrading")) != -1 ||
+           str.indexOf(QLatin1String("installing")) != -1 ||
+           str.indexOf(QLatin1String("reinstalling")) != -1)
+           && str.indexOf(QLatin1String("[")) != -1) return;
 
   if (str.indexOf(QLatin1String("%")) != -1) str.remove(QLatin1String("%"));
 
@@ -947,6 +955,8 @@ void PacmanExec::onReadOutputError()
  */
 void PacmanExec::onFinished(int exitCode, QProcess::ExitStatus es)
 {
+  m_retrievingPackages = false;
+
   if (m_commandExecuting == ectn_REMOVE_KCP_PKG)
   {
     if (UnixCommand::getLinuxDistro() == ectn_KAOS &&
